qemu-devel.nongnu.org archive mirror
 help / color / mirror / Atom feed
From: David Woodhouse <dwmw2@infradead.org>
To: qemu-devel@nongnu.org
Cc: "Paolo Bonzini" <pbonzini@redhat.com>,
	"Paul Durrant" <paul@xen.org>,
	"Joao Martins" <joao.m.martins@oracle.com>,
	"Ankur Arora" <ankur.a.arora@oracle.com>,
	"Philippe Mathieu-Daudé" <philmd@linaro.org>,
	"Thomas Huth" <thuth@redhat.com>,
	"Alex Bennée" <alex.bennee@linaro.org>,
	"Juan Quintela" <quintela@redhat.com>,
	"Dr . David Alan Gilbert" <dgilbert@redhat.com>,
	"Claudio Fontana" <cfontana@suse.de>
Subject: [RFC PATCH v4 03/47] xen: Add XEN_DISABLED mode and make it default
Date: Wed, 21 Dec 2022 01:05:39 +0000	[thread overview]
Message-ID: <20221221010623.1000191-4-dwmw2@infradead.org> (raw)
In-Reply-To: <20221221010623.1000191-1-dwmw2@infradead.org>

From: David Woodhouse <dwmw@amazon.co.uk>

Also set XEN_ATTACH mode in xen_init() to reflect the truth; not that
anyone ever cared before. It was *only* ever checked in xen_init_pv()
before.

Suggested-by: Paolo Bonzini <pbonzini@redhat.com>
Signed-off-by: David Woodhouse <dwmw@amazon.co.uk>
---
 accel/xen/xen-all.c  | 2 ++
 include/hw/xen/xen.h | 5 +++--
 softmmu/globals.c    | 2 +-
 3 files changed, 6 insertions(+), 3 deletions(-)

diff --git a/accel/xen/xen-all.c b/accel/xen/xen-all.c
index 69aa7d018b..2329556595 100644
--- a/accel/xen/xen-all.c
+++ b/accel/xen/xen-all.c
@@ -181,6 +181,8 @@ static int xen_init(MachineState *ms)
      * opt out of system RAM being allocated by generic code
      */
     mc->default_ram_id = NULL;
+
+    xen_mode = XEN_ATTACH;
     return 0;
 }
 
diff --git a/softmmu/globals.c b/softmmu/globals.c
index 527edbefdd..0a4405614e 100644
--- a/softmmu/globals.c
+++ b/softmmu/globals.c
@@ -63,5 +63,5 @@ QemuUUID qemu_uuid;
 bool qemu_uuid_set;
 
 uint32_t xen_domid;
-enum xen_mode xen_mode = XEN_EMULATE;
+enum xen_mode xen_mode = XEN_DISABLED;
 bool xen_domid_restrict;
diff --git a/include/hw/xen/xen.h b/include/hw/xen/xen.h
index afdf9c436a..82347e76a4 100644
--- a/include/hw/xen/xen.h
+++ b/include/hw/xen/xen.h
@@ -12,8 +12,9 @@
 
 /* xen-machine.c */
 enum xen_mode {
-    XEN_EMULATE = 0,  // xen emulation, using xenner (default)
-    XEN_ATTACH        // attach to xen domain created by libxl
+    XEN_DISABLED = 0, // xen support disabled (default)
+    XEN_ATTACH,       // attach to xen domain created by libxl
+    XEN_EMULATE,
 };
 
 extern uint32_t xen_domid;
-- 
2.35.3



  parent reply	other threads:[~2022-12-21  1:18 UTC|newest]

Thread overview: 51+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2022-12-21  1:05 [RFC PATCH v4 01/47] Xen HVM support under KVM David Woodhouse
2022-12-21  1:05 ` [RFC PATCH v4 01/47] include: import Xen public headers to include/standard-headers/ David Woodhouse
2022-12-21  1:05 ` [RFC PATCH v4 02/47] xen: add CONFIG_XENFV_MACHINE and CONFIG_XEN_EMU options for Xen emulation David Woodhouse
2022-12-21  1:05 ` David Woodhouse [this message]
2022-12-21 17:54   ` [RFC PATCH v4 03/47] xen: Add XEN_DISABLED mode and make it default Paul Durrant
2022-12-21  1:05 ` [RFC PATCH v4 04/47] i386/kvm: Add xen-version KVM accelerator property and init KVM Xen support David Woodhouse
2022-12-21  1:05 ` [RFC PATCH v4 05/47] i386/kvm: handle Xen HVM cpuid leaves David Woodhouse
2022-12-21  1:05 ` [RFC PATCH v4 06/47] i386/hvm: Set Xen vCPU ID in KVM David Woodhouse
2022-12-21 18:00   ` Paul Durrant
2022-12-21  1:05 ` [RFC PATCH v4 07/47] xen-platform: exclude vfio-pci from the PCI platform unplug David Woodhouse
2022-12-21  1:05 ` [RFC PATCH v4 08/47] xen-platform: allow its creation with XEN_EMULATE mode David Woodhouse
2022-12-21  1:05 ` [RFC PATCH v4 09/47] hw/xen_backend: refactor xen_be_init() David Woodhouse
2022-12-21  1:05 ` [RFC PATCH v4 10/47] i386/xen: handle guest hypercalls David Woodhouse
2022-12-21  1:05 ` [RFC PATCH v4 11/47] i386/xen: implement HYPERVISOR_xen_version David Woodhouse
2022-12-21 18:03   ` Paul Durrant
2022-12-21  1:05 ` [RFC PATCH v4 12/47] i386/xen: implement HYPERVISOR_sched_op, SCHEDOP_shutdown David Woodhouse
2022-12-21  1:05 ` [RFC PATCH v4 13/47] i386/xen: Implement SCHEDOP_poll and SCHEDOP_yield David Woodhouse
2022-12-21  1:05 ` [RFC PATCH v4 14/47] hw/xen: Add xen_overlay device for emulating shared xenheap pages David Woodhouse
2022-12-21  1:05 ` [RFC PATCH v4 15/47] i386/xen: add pc_machine_kvm_type to initialize XEN_EMULATE mode David Woodhouse
2022-12-21  1:05 ` [RFC PATCH v4 16/47] i386/xen: manage and save/restore Xen guest long_mode setting David Woodhouse
2022-12-21  1:05 ` [RFC PATCH v4 17/47] i386/xen: implement HYPERVISOR_memory_op David Woodhouse
2022-12-21  1:05 ` [RFC PATCH v4 18/47] i386/xen: implement XENMEM_add_to_physmap_batch David Woodhouse
2022-12-21  1:05 ` [RFC PATCH v4 19/47] i386/xen: implement HYPERVISOR_hvm_op David Woodhouse
2022-12-21  1:05 ` [RFC PATCH v4 20/47] i386/xen: implement HYPERVISOR_vcpu_op David Woodhouse
2022-12-21  1:05 ` [RFC PATCH v4 21/47] i386/xen: handle VCPUOP_register_vcpu_info David Woodhouse
2022-12-21  1:05 ` [RFC PATCH v4 22/47] i386/xen: handle VCPUOP_register_vcpu_time_info David Woodhouse
2022-12-21  1:05 ` [RFC PATCH v4 23/47] i386/xen: handle VCPUOP_register_runstate_memory_area David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 24/47] i386/xen: implement HYPERVISOR_event_channel_op David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 25/47] i386/xen: implement HVMOP_set_evtchn_upcall_vector David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 26/47] i386/xen: implement HVMOP_set_param David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 27/47] hw/xen: Add xen_evtchn device for event channel emulation David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 28/47] i386/xen: Add support for Xen event channel delivery to vCPU David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 29/47] hw/xen: Implement EVTCHNOP_status David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 30/47] hw/xen: Implement EVTCHNOP_close David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 31/47] hw/xen: Implement EVTCHNOP_unmask David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 32/47] hw/xen: Implement EVTCHNOP_bind_virq David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 33/47] hw/xen: Implement EVTCHNOP_bind_ipi David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 34/47] hw/xen: Implement EVTCHNOP_send David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 35/47] hw/xen: Implement EVTCHNOP_alloc_unbound David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 36/47] hw/xen: Implement EVTCHNOP_bind_interdomain David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 37/47] hw/xen: Implement EVTCHNOP_bind_vcpu David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 38/47] hw/xen: Implement EVTCHNOP_reset David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 39/47] i386/xen: add monitor commands to test event injection David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 40/47] hw/xen: Support HVM_PARAM_CALLBACK_TYPE_GSI callback David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 41/47] hw/xen: Support HVM_PARAM_CALLBACK_TYPE_PCI_INTX callback David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 42/47] kvm/i386: Add xen-gnttab-max-frames property David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 43/47] hw/xen: Add xen_gnttab device for grant table emulation David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 44/47] hw/xen: Support mapping grant frames David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 45/47] i386/xen: Implement HYPERVISOR_grant_table_op and GNTTABOP_[gs]et_verson David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 46/47] hw/xen: Implement GNTTABOP_query_size David Woodhouse
2022-12-21  1:06 ` [RFC PATCH v4 47/47] i386/xen: handle PV timer hypercalls David Woodhouse

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20221221010623.1000191-4-dwmw2@infradead.org \
    --to=dwmw2@infradead.org \
    --cc=alex.bennee@linaro.org \
    --cc=ankur.a.arora@oracle.com \
    --cc=cfontana@suse.de \
    --cc=dgilbert@redhat.com \
    --cc=joao.m.martins@oracle.com \
    --cc=paul@xen.org \
    --cc=pbonzini@redhat.com \
    --cc=philmd@linaro.org \
    --cc=qemu-devel@nongnu.org \
    --cc=quintela@redhat.com \
    --cc=thuth@redhat.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).